summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/tools/lcgenerator.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /kstars/kstars/tools/lcgenerator.cpp
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kstars/kstars/tools/lcgenerator.cpp')
-rw-r--r--kstars/kstars/tools/lcgenerator.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kstars/kstars/tools/lcgenerator.cpp b/kstars/kstars/tools/lcgenerator.cpp
index bc682bbb..1cc0b8e1 100644
--- a/kstars/kstars/tools/lcgenerator.cpp
+++ b/kstars/kstars/tools/lcgenerator.cpp
@@ -39,11 +39,11 @@
#include <kapplication.h>
-LCGenerator::LCGenerator( TQWidget* parent)
- : KDialogBase( parent, "lcgenerator", false, i18n( "AAVSO Light Curve Generator"),0) , Hostprefix("http://www.aavso.org/cgi-bin/kstar.pl"), JDCutOff(2437600)
+LCGenerator::LCGenerator( TQWidget* tqparent)
+ : KDialogBase( tqparent, "lcgenerator", false, i18n( "AAVSO Light Curve Generator"),0) , Hostprefix("http://www.aavso.org/cgi-bin/kstar.pl"), JDCutOff(2437600)
{
- ksw = (KStars*) parent;
+ ksw = (KStars*) tqparent;
createGUI();
downloadJob = 0;
@@ -69,10 +69,10 @@ void LCGenerator::createGUI()
StarInfoBox = new TQGroupBox( page, "StarInfoBox" );
StarInfoBox->setColumnLayout(0, Qt::Vertical );
- StarInfoBox->layout()->setSpacing( 6 );
- StarInfoBox->layout()->setMargin( 11 );
- StarInfoBoxLayout = new TQVBoxLayout( StarInfoBox->layout() );
- StarInfoBoxLayout->setAlignment( Qt::AlignTop );
+ StarInfoBox->tqlayout()->setSpacing( 6 );
+ StarInfoBox->tqlayout()->setMargin( 11 );
+ StarInfoBoxLayout = new TQVBoxLayout( StarInfoBox->tqlayout() );
+ StarInfoBoxLayout->tqsetAlignment( TQt::AlignTop );
DesignHLayout = new TQHBoxLayout( 0, 0, 6, "DesignHLayout");
@@ -125,10 +125,10 @@ void LCGenerator::createGUI()
DataSelectBox = new TQGroupBox( page, "DataSelectBox" );
DataSelectBox->setColumnLayout(0, Qt::Vertical );
- DataSelectBox->layout()->setSpacing( 6 );
- DataSelectBox->layout()->setMargin( 11 );
- DataSelectBoxLayout = new TQVBoxLayout( DataSelectBox->layout() );
- DataSelectBoxLayout->setAlignment( Qt::AlignTop );
+ DataSelectBox->tqlayout()->setSpacing( 6 );
+ DataSelectBox->tqlayout()->setMargin( 11 );
+ DataSelectBoxLayout = new TQVBoxLayout( DataSelectBox->tqlayout() );
+ DataSelectBoxLayout->tqsetAlignment( TQt::AlignTop );
VisualCheck = new TQCheckBox( DataSelectBox, "VisualCheck" );
VisualCheck->setChecked( TRUE );
@@ -398,7 +398,7 @@ void LCGenerator::DownloadCurve(TQString FinalStartDate, TQString FinalEndDate,
KURL url(buf);
TQString message = i18n( "Light Curve produced by the American Amateur Variable Star Observers" );
// parent of imageview is KStars
new ImageViewer(&url, message, ksw, "lightcurve");
}
@@ -471,7 +471,7 @@ downloadJob = 0;
void LCGenerator::closeEvent (TQCloseEvent *ev)
{
if (ev) // not if closeEvent (0) is called, because segfault
- ev->accept(); // parent-widgets should not get this event, so it will be filtered
+ ev->accept(); // tqparent-widgets should not get this event, so it will be filtered
//this->~LCGenerator(); // destroy the object, so the object can only allocated with operator new, not as a global/local variable
}
@@ -398,7 +398,7 @@ void LCGenerator::DownloadCurve(TQString FinalStartDate, TQString FinalEndDate,
KURL url(buf);
TQString message = i18n( "Light Curve produced by the American Amateur Variable Star Observers" );
- // parent of imageview is KStars
+ // tqparent of imageview is KStars
new ImageViewer(&url, message, ksw, "lightcurve");
}